@@ -40,6 +40,13 @@ struct XTermDriver {
   } initialised;
 };
 
+enum {
+  TERMCTL_CAP_CURSORSHAPE = TICKIT_TERMCTL_PRIVATE_XTERM + 1,
+  TERMCTL_CAP_SLRM,
+  TERMCTL_CAP_CSI_SUB_COLON,
+  TERMCTL_CAP_RGB8,
+};
+
 static bool print(TickitTermDriver *ttd, const char *str, size_t len)
 {
   tickit_termdrv_write_str(ttd, str, len);
@@ -327,6 +334,24 @@ static bool getctl_int(TickitTermDriver *ttd, TickitTermCtl ctl, int *value)
 {
   struct XTermDriver *xd = (struct XTermDriver *)ttd;
 
+  switch((int)ctl) {
+    case TERMCTL_CAP_CURSORSHAPE:
+      *value = xd->cap.cursorshape;
+      return true;
+
+    case TERMCTL_CAP_SLRM:
+      *value = xd->cap.slrm;
+      return true;
+
+    case TERMCTL_CAP_CSI_SUB_COLON:
+      *value = xd->cap.csi_sub_colon;
+      return true;
+
+    case TERMCTL_CAP_RGB8:
+      *value = xd->cap.rgb8;
+      return true;
+  }
+
   switch(ctl) {
     case TICKIT_TERMCTL_ALTSCREEN:
       *value = xd->mode.altscreen;
@@ -378,6 +403,14 @@ static bool setctl_int(TickitTermDriver *ttd, TickitTermCtl ctl, int value)
 {
   struct XTermDriver *xd = (struct XTermDriver *)ttd;
 
+  switch((int)ctl) {
+    case TERMCTL_CAP_RGB8:
+      // Allow forcing this on/off because maybe the user (or at least the
+      // calling program) has a better idea than our probing via DECRQSS
+      xd->cap.rgb8 = !!value;
+      return true;
+  }
+
   switch(ctl) {
     case TICKIT_TERMCTL_ALTSCREEN:
       if(!xd->mode.altscreen == !value)
@@ -479,6 +512,8 @@ static void start(TickitTermDriver *ttd)
    * It doens't hurt at this point to clear the current line just in case.
    */
   tickit_termdrv_write_strf(ttd, "\e[G\e[K");
+
+  tickit_term_flush(ttd->tt);
 }
 
 static bool started(TickitTermDriver *ttd)
@@ -491,8 +526,10 @@ static bool started(TickitTermDriver *ttd)
          xd->initialised.slrm;
 }
 
-static void gotkey_modereport(struct XTermDriver *xd, int initial, int mode, int value)
+static int on_modereport(TickitTermDriver *ttd, int initial, int mode, int value)
 {
+  struct XTermDriver *xd = (struct XTermDriver *)ttd;
+
   if(initial == '?') // DEC mode
     switch(mode) {
       case 12: // Cursor blink
@@ -511,10 +548,14 @@ static void gotkey_modereport(struct XTermDriver *xd, int initial, int mode, int
         xd->initialised.slrm = 1;
         break;
     }
+
+  return 1;
 }
 
-static void gotkey_decrqss(struct XTermDriver *xd, const char *args, size_t arglen)
+static int on_decrqss(TickitTermDriver *ttd, const char *args, size_t arglen)
 {
+  struct XTermDriver *xd = (struct XTermDriver *)ttd;
+
   if(strneq(args + arglen - 2, " q", 2)) { // DECSCUSR
     int value;
     if(sscanf(args, "%d", &value)) {
@@ -530,7 +571,7 @@ static void gotkey_decrqss(struct XTermDriver *xd, const char *args, size_t argl
     while(arglen && args[0] >= '0' && args[0] <= '9')
       args++, arglen--;
     if(!arglen)
-      return;
+      return 1;
 
     if(args[0] == ':')
       xd->cap.csi_sub_colon = 1;
@@ -541,33 +582,8 @@ static void gotkey_decrqss(struct XTermDriver *xd, const char *args, size_t argl
     if(sscanf(args, "%d", &value) && value == 2)
       xd->cap.rgb8 = 1;
   }
-}
 
-static int gotkey(TickitTermDriver *ttd, TermKey *tk, const TermKeyKey *key)
-{
-  struct XTermDriver *xd = (struct XTermDriver *)ttd;
-
-  if(key->type == TERMKEY_TYPE_MODEREPORT) {
-    int initial, mode, value;
-    termkey_interpret_modereport(tk, key, &initial, &mode, &value);
-    gotkey_modereport(xd, initial, mode, value);
-
-    return 1;
-  }
-  else if(key->type == TERMKEY_TYPE_DCS) {
-    const char *dcs;
-    if(termkey_interpret_string(tk, key, &dcs) != TERMKEY_RES_KEY)
-      return 0;
-
-    if(strneq(dcs, "1$r", 3)) { // Successful DECRQSS
-      gotkey_decrqss(xd, dcs + 3, strlen(dcs + 3));
-    }
-
-    // Just eat all the DCSes
-    return 1;
-  }
-
-  return 0;
+  return 1;
 }
 
 static void teardown(TickitTermDriver *ttd)
@@ -625,7 +641,8 @@ static TickitTermDriverVTable xterm_vtable = {
   .getctl_int = getctl_int,
   .setctl_int = setctl_int,
   .setctl_str = setctl_str,
-  .gotkey     = gotkey,
+  .on_modereport = on_modereport,
+  .on_decrqss    = on_decrqss,
 };
 
 static TickitTermDriver *new(const TickitTermProbeArgs *args)
@@ -644,6 +661,7 @@ static TickitTermDriver *new(const TickitTermProbeArgs *args)
 
   struct XTermDriver *xd = malloc(sizeof(struct XTermDriver));
   xd->driver.vtable = &xterm_vtable;
+  xd->driver.name   = tickit_termdrv_info_xterm.name;
 
   xd->dcs_offset = -1;
 
@@ -657,6 +675,37 @@ static TickitTermDriver *new(const TickitTermProbeArgs *args)
   return (TickitTermDriver*)xd;
 }
 
-TickitTermDriverProbe tickit_termdrv_probe_xterm = {
-  .new = new,
+static const char *ctlname(TickitTermCtl ctl)
+{
+  switch((int)ctl) {
+    case TERMCTL_CAP_CURSORSHAPE:   return "xterm.cap_cursorshape";
+    case TERMCTL_CAP_SLRM:          return "xterm.cap_slrm";
+    case TERMCTL_CAP_CSI_SUB_COLON: return "xterm.cap_csi_sub_colon";
+    case TERMCTL_CAP_RGB8:          return "xterm.cap_rgb8";
+
+    default:
+      return NULL;
+  }
+}
+
+static TickitType ctltype(TickitTermCtl ctl)
+{
+  switch((int)ctl) {
+    case TERMCTL_CAP_CURSORSHAPE:
+    case TERMCTL_CAP_SLRM:
+    case TERMCTL_CAP_CSI_SUB_COLON:
+    case TERMCTL_CAP_RGB8:
+      return TICKIT_TYPE_BOOL;
+
+    default:
+      return TICKIT_TYPE_NONE;
+  }
+}
+
+TickitTermDriverInfo tickit_termdrv_info_xterm = {
+  .name       = "xterm",
+  .new        = new,
+  .privatectl = TICKIT_TERMCTL_PRIVATE_XTERM,
+  .ctlname    = ctlname,
+  .ctltype    = ctltype,
 };
