@@ -575,6 +575,10 @@ void tickit_window_expose(TickitWindow *win, const TickitRect *exposed)
     return;
 
   if(!win->is_root) {
+    if(!win->parent)
+      /* During cleanup at shutdown this might be empty already */
+      return;
+
     tickit_rect_translate(&damaged, win->rect.top, win->rect.left);
     tickit_window_expose(win->parent, &damaged);
     return;
@@ -882,6 +886,7 @@ static void _do_hierarchy_change(HierarchyChangeType change, TickitWindow *paren
     case TICKIT_HIERARCHY_REMOVE:
       fmt = "Window " WINDOW_PRINTF_FMT " removes " WINDOW_PRINTF_FMT;
       _do_hierarchy_remove(parent, win);
+      win->parent = NULL;
       if(parent->focused_child && parent->focused_child == win)
         parent->focused_child = NULL;
       break;
@@ -1381,7 +1386,7 @@ done:
   return ret;
 }
 
-const char *tickit_window_ctlname(TickitWindowCtl ctl)
+const char *tickit_windowctl_name(TickitWindowCtl ctl)
 {
   switch(ctl) {
     case TICKIT_WINCTL_STEAL_INPUT:        return "steal-input";
@@ -1395,18 +1400,18 @@ const char *tickit_window_ctlname(TickitWindowCtl ctl)
   return NULL;
 }
 
-TickitWindowCtl tickit_window_lookup_ctl(const char *name)
+TickitWindowCtl tickit_windowctl_lookup(const char *name)
 {
   const char *s;
 
   for(TickitWindowCtl ctl = 1; ctl < TICKIT_N_WINCTLS; ctl++)
-    if((s = tickit_window_ctlname(ctl)) && streq(name, s))
+    if((s = tickit_windowctl_name(ctl)) && streq(name, s))
       return ctl;
 
   return -1;
 }
 
-TickitType tickit_window_ctltype(TickitWindowCtl ctl)
+TickitType tickit_windowctl_type(TickitWindowCtl ctl)
 {
   switch(ctl) {
     case TICKIT_WINCTL_STEAL_INPUT:
@@ -1423,3 +1428,7 @@ TickitType tickit_window_ctltype(TickitWindowCtl ctl)
   }
   return TICKIT_TYPE_NONE;
 }
+
+const char *tickit_window_ctlname(TickitWindowCtl ctl) { return tickit_windowctl_name(ctl); }
+TickitWindowCtl tickit_window_lookup_ctl(const char *name) { return tickit_windowctl_lookup(name); }
+TickitType tickit_window_ctltype(TickitWindowCtl ctl) { return tickit_windowctl_type(ctl); }
